import React, {PureComponent} from 'react';
import Banner from "./components/Banner";
import ListWrapper from './components/List';
import Feature from "./components/Feature";
import {HomeWrapper, MainWrapper} from './style';
import {actionCreators} from "./store";
import {connect} from "react-redux";
import {getrand} from "../../lib/public";

class Home extends PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            banner: '',
            bannerList: [
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(59).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(53).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(70).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(60).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(46).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(73).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(63).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(74).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(72).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(62).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(7).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(23).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(28).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(38).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(43).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(46).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(54).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(62).jpg'},
                {img: 'https://cos.nosum.cn/nosum/blog/1/nosum-blog-1%20(73).jpg'}
            ],
            innerHeight: window.innerHeight,
        };
        this.getBanner = this.getBanner.bind(this);
    }

    render() {
        const {banner, innerHeight} = this.state;
        const {userInfo, featureList, ListImg, socialList} = this.props;
        return (
            <HomeWrapper>
                <Banner banner={banner} innerHeight={innerHeight} getBanner={this.getBanner} userInfo={userInfo} socialList={socialList}/>
                <MainWrapper id='content'>
                    <Feature featureList={featureList} ListImg={ListImg}/>
                    <ListWrapper/>
                </MainWrapper>
            </HomeWrapper>
        )
    }

    componentDidMount() {
        this.changeInnerHeight();
        this.getBanner();
        this.props.getFeature();
        this.props.getSocialList()
    }

    getBanner() {
        const banner = this.state.bannerList;
        const num = getrand(0, banner.length - 1);
        this.setState({
            banner: `url('${banner[num].img}')`
        })
    }

    changeInnerHeight() {
        window.onresize = () => {
            this.setState({
                innerHeight: window.innerHeight,
            })
        }
    }
}

const mapState = (state) => {
    return {
        userInfo: state.getIn(['header', 'userInfo']),
        featureList: state.getIn(['home', 'featureList']),
        ListImg: state.getIn(['image', 'ListImg']),
        socialList: state.getIn(['home', 'socialList']),
    }
};

const mapDispatch = (dispatch) => {
    return {
        getFeature() {
            dispatch(actionCreators.getFeature());
        },
        getSocialList() {
            dispatch(actionCreators.getSocialList());
        },
    }
};

export default connect(mapState, mapDispatch)(Home);
